@@ -1,4 +1,8 @@
 import numpy as np
+from prettytable import PrettyTable
+from .tools import prod
+
+#Tensor Class
 
 class tensor(object):
 
@@ -7,16 +11,16 @@ class tensor(object):
 	dtype = None
 
 	def __init__(self, data = None, shape = None):
+
+		if shape == None:
+			shape = data.shape
 		super(tensor, self).__init__()
 		self.data = np.array(data)
 		self.shape = tuple(shape)
 		self.dtype = data.dtype
 
 	def size(self):
-		ret = 1
-		for i in range(0,len(self.shape)):
-			ret = ret * self.shape[i]
-		return  ret
+		return prod(self.shape)
 
 	def copy(self):
 		return tensor(self.data.copy(),self.shape)
@@ -28,4 +32,12 @@ class tensor(object):
 		return len(self.shape)
 
 	def tendtype(self):
-		return self.dtype
\ No newline at end of file
+		return self.dtype
+
+	def information(self):
+		print('\tTensor\tInformation')
+		table = PrettyTable(['Order', 'Shape', 'Size'])
+		table.add_row([self.ndims(), self.shape, self.size()])
+		table.reversesort = False
+		table.border = 1
+		print(table)
\ No newline at end of file
